@@ -10,9 +10,7 @@ def assert_scaffolded_without_cli(module_file) -> t.Callable[[str], None]:
 
     def assert_project_generated_without_cli(project_dir: str) -> None:
         get_file: t.Callable[[str], str] = module_file(project_dir)
-        assert all(
-            not path.isfile(get_file(file_name)) for file_name in CLI_RELATED_FILES
-        )
+        assert all(not path.isfile(get_file(file_name)) for file_name in CLI_RELATED_FILES)
 
     return assert_project_generated_without_cli
 
@@ -75,9 +73,7 @@ def test_supported_python_interpreters(
 
 
 @pytest.fixture
-def assert_interpreters_array_in_build_matrix() -> (
-    t.Callable[[str, t.Sequence[str]], None]
-):
+def assert_interpreters_array_in_build_matrix() -> t.Callable[[str, t.Sequence[str]], None]:
     """Test that Job Matrix is generated correctly and stored as Workflow env var.
 
     Test proper generation of github workflow config yaml for lines such as:
